==> haskell-nonce-1.0.7-397-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nonce
version:              1.0.7
visibility:           public
id:                   nonce-1.0.7-9cFIXF7uaQe11wB3vt9N5F
key:                  nonce-1.0.7-9cFIXF7uaQe11wB3vt9N5F
license:              BSD-3-Clause
copyright:            (c) 2014 Prowdsponsor
maintainer:           Prowdsponsor <opensource@prowdsponsor.com>
author:               Felipe Lessa <felipe.lessa@prowdsponsor.com>
homepage:             https://github.com/prowdsponsor/nonce
synopsis:             Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.

    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.

category:             Cryptography
abi:                  48e0126be353667c03f7def1f3972d44
exposed:              True
exposed-modules:      Crypto.Nonce
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nonce-1.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nonce-1.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nonce-1.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nonce
hs-libraries:         HSnonce-1.0.7-9cFIXF7uaQe11wB3vt9N5F
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-GswEt3eOHYLA64palw0j2S
    bytestring-0.11.5.3 entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    text-2.0.2 transformers-0.5.6.2
    unliftio-0.2.25.1-DyweKXwNyOA6bCdvyvzfdZ
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html:         /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nonce-1.0.7-398-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nonce.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nonce
version:              1.0.7
visibility:           public
id:                   nonce-1.0.7-EHdym0fwJLoLjyOg7aJVkg
key:                  nonce-1.0.7-EHdym0fwJLoLjyOg7aJVkg
license:              BSD-3-Clause
copyright:            (c) 2014 Prowdsponsor
maintainer:           Prowdsponsor <opensource@prowdsponsor.com>
author:               Felipe Lessa <felipe.lessa@prowdsponsor.com>
homepage:             https://github.com/prowdsponsor/nonce
synopsis:             Generate cryptographic nonces.
description:
    According to the Wikipedia, a nonce is an arbitrary number used
    only once in a cryptographic communication.  This package
    contain helper functions for generating nonces.

    There are many kinds of nonces used in different situations.
    It'\''s not guaranteed that by using the nonces from this package
    you won'\''t have any security issues.  Please make sure that the
    nonces generated via this package are usable on your design.

category:             Cryptography
abi:                  ad4a81f245bf4632803b7b4c5d09ad22
exposed:              True
exposed-modules:      Crypto.Nonce
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nonce-1.0.7
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nonce-1.0.7
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nonce-1.0.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nonce
hs-libraries:         HSnonce-1.0.7-EHdym0fwJLoLjyOg7aJVkg
depends:
    base-4.17.2.1 base64-bytestring-1.2.1.0-AW9I0WOkr0IYZNZquGJUP
    bytestring-0.11.5.3 entropy-0.4.1.11-KgGl1Y7Pn5mDV1IyWdAGFR
    text-2.0.2 transformers-0.5.6.2
    unliftio-0.2.25.1-K65YKtoeNxU8ODiXOzaxtw
    unliftio-core-0.2.1.0-1JwPsdkrVim6892Z5vBeIT

haddock-interfaces:   /usr/share/doc/haskell-nonce/html/nonce.haddock
haddock-html:         /usr/share/doc/haskell-nonce/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
